==> sghi_core-0.2.31.tar.gz: lib/afya_moja_core/src/presentation/country_code_picker.dart <==
// Flutter imports:
import 'package:flutter/material.dart';
import 'package:sghi_core/afya_moja_core/src/behavior_subjects.dart';
import 'package:sghi_core/afya_moja_core/src/enums.dart';
import 'package:sghi_core/afya_moja_core/src/utils.dart';

/// [MyAfyaHubCountryPicker] is used in [MyAfyaHubPhoneLoginPage] select Country Code
///
/// It takes in a required [onChanged] parameter
class MyAfyaHubCountryPicker extends StatefulWidget {
  const MyAfyaHubCountryPicker({
    super.key,
    this.selectCountryKey,
    required this.onChanged,
  });

  final void Function(String) onChanged;
  final Key? selectCountryKey;

  @override
  _MyAfyaHubCountryPickerState createState() => _MyAfyaHubCountryPickerState();
}

class _MyAfyaHubCountryPickerState extends State<MyAfyaHubCountryPicker> {
  PhoneInputBehaviorSubject phoneInputBehaviorSubject =
      PhoneInputBehaviorSubject();

  Country _country = Country.kenya;

  @override
  void initState() {
    super.initState();
    phoneInputBehaviorSubject.countryCode.add(getCountry(_country)!['code']!);
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      behavior: HitTestBehavior.opaque,
      key: widget.selectCountryKey,
      onTap: () async {
        final Country? result = await selectCountryModalBottomSheet(context);
        if (result != null) {
          setState(() {
            _country = result;
            final String countryCode = getCountry(_country)!['code']!;
            widget.onChanged(countryCode);
            phoneInputBehaviorSubject.countryCode.add(countryCode);
          });
        }
      },
      child: Row(
        children: <Widget>[
          Text(
            getCountry(this._country)!['code']!,
            key: const Key('countrySelectedKey'),
            style: const TextStyle(
              fontWeight: FontWeight.w300,
              color: Colors.black,
              fontSize: 15,
            ),
          ),
          const SizedBox(width: 10),
          Image.asset(
            getCountry(this._country)!['flag']!,
            height: 20,
          ),
          const Icon(Icons.arrow_drop_down),
        ],
      ),
    );
  }
}

==> sghi_core-0.3.70.tar.gz: lib/afya_moja_core/src/presentation/country_code_picker.dart <==
// Flutter imports:
import 'package:flutter/material.dart';
import 'package:sghi_core/afya_moja_core/src/behavior_subjects.dart';
import 'package:sghi_core/afya_moja_core/src/enums.dart';
import 'package:sghi_core/afya_moja_core/src/utils.dart';

/// [MyAfyaHubCountryPicker] is used in [MyAfyaHubPhoneLoginPage] select Country Code
///
/// It takes in a required [onChanged] parameter
class MyAfyaHubCountryPicker extends StatefulWidget {
  const MyAfyaHubCountryPicker({
    super.key,
    this.selectCountryKey,
    required this.onChanged,
  });

  final void Function(String) onChanged;
  final Key? selectCountryKey;

  @override
  _MyAfyaHubCountryPickerState createState() => _MyAfyaHubCountryPickerState();
}

class _MyAfyaHubCountryPickerState extends State<MyAfyaHubCountryPicker> {
  PhoneInputBehaviorSubject phoneInputBehaviorSubject =
      PhoneInputBehaviorSubject();

  Country _country = Country.KENYA;

  @override
  void initState() {
    super.initState();
    phoneInputBehaviorSubject.countryCode.add(getCountry(_country)!['code']!);
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      behavior: HitTestBehavior.opaque,
      key: widget.selectCountryKey,
      onTap: () async {
        final Country? result = await selectCountryModalBottomSheet(context);
        if (result != null) {
          setState(() {
            _country = result;
            final String countryCode = getCountry(_country)!['code']!;
            widget.onChanged(countryCode);
            phoneInputBehaviorSubject.countryCode.add(countryCode);
          });
        }
      },
      child: Row(
        children: <Widget>[
          Text(
            getCountry(this._country)!['code']!,
            key: const Key('countrySelectedKey'),
            style: const TextStyle(
              fontWeight: FontWeight.w300,
              color: Colors.black,
              fontSize: 15,
            ),
          ),
          const SizedBox(width: 10),
          Image.asset(
            getCountry(this._country)!['flag']!,
            height: 20,
          ),
          const Icon(Icons.arrow_drop_down),
        ],
      ),
    );
  }
}
